debugapi

package
v0.0.0-...-dd16f27 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 12, 2020 License: BSD-3-Clause Imports: 2 Imported by: 0

Documentation

Index

Constants

const ServiceName = "DebugAPI"

ServiceName is the name of the service as defined in the design. This is the same value that is set in the endpoint request contexts under the ServiceKey key.

Variables

var MethodNames = [1]string{"version"}

MethodNames lists the service method names as defined in the design. These are the same values that are set in the endpoint request contexts under the MethodKey key.

Functions

func NewVersionEndpoint

func NewVersionEndpoint(s Service) goa.Endpoint

NewVersionEndpoint returns an endpoint function that calls the method "version" of service "DebugAPI".

Types

type Client

type Client struct {
	VersionEndpoint goa.Endpoint
}

Client is the "DebugAPI" service client.

func NewClient

func NewClient(version goa.Endpoint) *Client

NewClient initializes a "DebugAPI" service client given the endpoints.

func (*Client) Version

func (c *Client) Version(ctx context.Context) (res *VersionResult, err error)

Version calls the "version" endpoint of the "DebugAPI" service.

type Endpoints

type Endpoints struct {
	Version goa.Endpoint
}

Endpoints wraps the "DebugAPI" service endpoints.

func NewEndpoints

func NewEndpoints(s Service) *Endpoints

NewEndpoints wraps the methods of the "DebugAPI" service with endpoints.

func (*Endpoints) Use

func (e *Endpoints) Use(m func(goa.Endpoint) goa.Endpoint)

Use applies the given middleware to all the "DebugAPI" service endpoints.

type Service

type Service interface {
	// Returns relayerd version.
	Version(context.Context) (res *VersionResult, err error)
}

DebugAPI implements debugging API methods. Not part of any standard (yet).

type VersionResult

type VersionResult struct {
	// Relayerd code version.
	Version string
	// Additional meta data.
	MetaData map[string]string
}

VersionResult is the result type of the DebugAPI service version method.

Jump to