Documentation
¶
Index ¶
Constants ¶
const ServiceName = "DebugAPI"
ServiceName is the name of the service as defined in the design. This is the same value that is set in the endpoint request contexts under the ServiceKey key.
Variables ¶
var MethodNames = [1]string{"version"}
MethodNames lists the service method names as defined in the design. These are the same values that are set in the endpoint request contexts under the MethodKey key.
Functions ¶
func NewVersionEndpoint ¶
NewVersionEndpoint returns an endpoint function that calls the method "version" of service "DebugAPI".
Types ¶
type Client ¶
Client is the "DebugAPI" service client.
type Endpoints ¶
Endpoints wraps the "DebugAPI" service endpoints.
func NewEndpoints ¶
NewEndpoints wraps the methods of the "DebugAPI" service with endpoints.
type Service ¶
type Service interface {
// Returns relayerd version.
Version(context.Context) (res *VersionResult, err error)
}
DebugAPI implements debugging API methods. Not part of any standard (yet).
type VersionResult ¶
type VersionResult struct {
// Relayerd code version.
Version string
// Additional meta data.
MetaData map[string]string
}
VersionResult is the result type of the DebugAPI service version method.